@@ -175,8 +175,13 @@ def _get_bq_service(credentials=None, service_url=None):
     assert credentials, 'Must provide ServiceAccountCredentials'
 
     http = credentials.authorize(Http())
-    service = build('bigquery', 'v2', http=http,
-                    discoveryServiceUrl=service_url)
+    service = build(
+        'bigquery',
+        'v2',
+        http=http,
+        discoveryServiceUrl=service_url,
+        cache_discovery=False
+    )
 
     return service
 
@@ -1482,13 +1487,13 @@ class BigQueryClient(object):
         project_id = self._get_project_id(project_id)
 
         result = self.bigquery.tables().list(
-            projectId=self.project_id,
+            projectId=project_id,
             datasetId=dataset_id).execute(num_retries=self.num_retries)
 
         page_token = result.get('nextPageToken')
         while page_token:
             res = self.bigquery.tables().list(
-                projectId=self.project_id,
+                projectId=project_id,
                 datasetId=dataset_id,
                 pageToken=page_token
             ).execute(num_retries=self.num_retries)
